@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2017 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -28,5 +28,7 @@ from .health_qrcodes import *
 def register():
     Pool.register(
         Patient,
+        Appointment,
         Newborn,
+        LabTest,
         module='health_qrcodes', type_='model')
